@@ -1,7 +1,9 @@
 pub(crate) use aggregate::Aggregate;
+pub(crate) use event::Event;
 pub(crate) use event_type::EventType;
 pub(crate) use typeid::TypeId;
 
 mod aggregate;
+mod event;
 mod event_type;
 mod typeid;
